% neuron parameters
Vreset = -70.0;  %mV
Vth = -55.0;  %mV
Cm = 250.0;  %uF

% simulation parameters
simtime = 1.0;  %s
sampling_time = 0.001;  %s
samples = round(simtime/sampling_time);
t = (1:samples)*sampling_time;

% external input current (mA)
Iext = 50.0*ones(samples, 1);  %mA
Iext(501:end) = 2*Iext(501:end);

% membrane potential
Vm = zeros(samples, 1);  %mV
Vm(1) = Vreset;

%simulation
spikes = zeros(samples, 1);
for i=2:samples
    dVm = Iext(i)/Cm;
    Vm(i) = Vm(i-1)+dVm;
    
    % spike
    if (Vm(i) > Vth)
        Vm(i) = Vreset;
        spikes(i) = 1;
    end
end

% post-synaptic currents
ts = 0.02;  %s
delay = 0.025;  %s

I = zeros(samples, 1);  %mA
for i=1:samples
   if (spikes(i) == 1)
       for k=i+delay/sampling_time:samples
           tt = (k-i)*sampling_time;
           I(k) = tt/ts*exp(-tt/ts);
       end
   end
end

% plotting
figure;
subplot(2, 1, 1);
plot(t, Vm);
xlabel('time (s)');
ylabel('V_m (mV)');

subplot(2, 1, 2);
plot(t, I);
xlabel('time (s)');
ylabel('I (mA)');